==> haskell-hookup-0.8-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hookup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hookup
version:              0.8
visibility:           public
id:                   hookup-0.8-Ivv4vJnS2ObBZW2byZtExc
key:                  hookup-0.8-Ivv4vJnS2ObBZW2byZtExc
license:              ISC
copyright:            2016-2020 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:
    Abstraction over creating network connections with SOCKS5 and TLS

description:
    This package provides an abstraction for communicating with line-oriented
    network services while abstracting over the use of SOCKS5 and TLS (via OpenSSL)

category:             Network
abi:                  1ed7179e9bab7b79d6361a705346e833
exposed:              True
exposed-modules:      Hookup Hookup.OpenSSL
hidden-modules:       Hookup.Socks5 Hookup.Concurrent
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hookup-0.8
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hookup-0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hookup
hs-libraries:         HShookup-0.8-Ivv4vJnS2ObBZW2byZtExc
depends:
    HsOpenSSL-0.11.7.6-LDZqvw3Iqc2IePqfSKUeEz
    HsOpenSSL-x509-system-0.1.0.4-KTVXc0JyFAGAk5v2PEekLI
    async-2.2.5-BrTWnMUC2zMDZ2E35FeCoi
    attoparsec-0.14.4-LhljGCg6FhTCY2JBHQACd0 base-4.16.4.0
    bytestring-0.11.4.0 network-3.1.4.0-9VcJfHdcvDFHTEtyJROzpl
    stm-2.5.0.2

haddock-interfaces:   /usr/share/doc/haskell-hookup/html/hookup.haddock
haddock-html:         /usr/share/doc/haskell-hookup/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hookup-0.8-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hookup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hookup
version:              0.8
visibility:           public
id:                   hookup-0.8-C6gV7Ktsswu8nRw6Oa5OzZ
key:                  hookup-0.8-C6gV7Ktsswu8nRw6Oa5OzZ
license:              ISC
copyright:            2016-2020 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:
    Abstraction over creating network connections with SOCKS5 and TLS

description:
    This package provides an abstraction for communicating with line-oriented
    network services while abstracting over the use of SOCKS5 and TLS (via OpenSSL)

category:             Network
abi:                  3e15acf9869162c65410f933aee6fb02
exposed:              True
exposed-modules:      Hookup Hookup.OpenSSL
hidden-modules:       Hookup.Socks5 Hookup.Concurrent
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hookup-0.8
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hookup-0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hookup
hs-libraries:         HShookup-0.8-C6gV7Ktsswu8nRw6Oa5OzZ
depends:
    HsOpenSSL-0.11.7.7-9ZcQkcs8vCjAMbXNWzPSMd
    HsOpenSSL-x509-system-0.1.0.4-9cfh3ZieA0pBfDtkIPLmba
    async-2.2.5-BrTWnMUC2zMDZ2E35FeCoi
    attoparsec-0.14.4-LhljGCg6FhTCY2JBHQACd0 base-4.16.4.0
    bytestring-0.11.4.0 network-3.1.4.0-9VcJfHdcvDFHTEtyJROzpl
    stm-2.5.0.2

haddock-interfaces:   /usr/share/doc/haskell-hookup/html/hookup.haddock
haddock-html:         /usr/share/doc/haskell-hookup/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
